# Perseus: Core Python Library

Perseus Core Python Library is a repository of reusable Python components to be shared with Python projects integrating Perseus RESTful API server framework.

These components have minimal dependencies on other libraries, so that they can be deployed easily.  In addition, these components will keep their interfaces as stable as possible, so that other Python projects can integrate these components without having to worry about changes in the future.


To install the Perseus Core Python Library, enter the follow command line:

```bash
$ pip install perseus-core-library
```
